==> socnetv_2.2.orig.tar.gz: socnetv-2.2/src/dialogclusteringhierarchical.h <==
/***************************************************************************
 SocNetV: Social Network Visualizer
 version: 2.2
 Written in Qt
 
                         dialogclusteringhierarchical.h  -  description
                             -------------------
    copyright         : (C) 2005-2017 by Dimitris B. Kalamaras
    project site      : http://socnetv.org

 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                              *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/

#ifndef DIALOGCLUSTERINGHIERARCHICAL_H
#define DIALOGCLUSTERINGHIERARCHICAL_H

#include <QDialog>
#include "ui_dialogclusteringhierarchical.h"
 

class DialogClusteringHierarchical: public QDialog
{
	Q_OBJECT
public:
    DialogClusteringHierarchical (QWidget *parent = 0, QString preselectMatrix = "");
    ~DialogClusteringHierarchical();
public slots:
	void gatherData();
signals:
    void userChoices(const QString &matrix,
                     const QString &similarityMeasure,
                     const QString &linkageCriterion,
                     const bool &diagonal,
                     const bool &diagram);
private slots:
    void on_buttonBox_accepted();

    void on_buttonBox_rejected();

    void matrixChanged(const QString &matrix);
private:
    Ui::DialogClusteringHierarchical ui;
    QStringList matrixList, measureList, linkageList;

};



#endif

==> socnetv_2.4.orig.tar.gz: socnetv-2.4/src/dialogclusteringhierarchical.h <==
/***************************************************************************
 SocNetV: Social Network Visualizer
 version: 2.4
 Written in Qt
 
                         dialogclusteringhierarchical.h  -  description
                             -------------------
    copyright         : (C) 2005-2018 by Dimitris B. Kalamaras
    project site      : http://socnetv.org

 ***************************************************************************/

/*******************************************************************************
*     This program is free software: you can redistribute it and/or modify     *
*     it under the terms of the GNU General Public License as published by     *
*     the Free Software Foundation, either version 3 of the License, or        *
*     (at your option) any later version.                                      *
*                                                                              *
*     This program is distributed in the hope that it will be useful,          *
*     but WITHOUT ANY WARRANTY; without even the implied warranty of           *
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
*     GNU General Public License for more details.                             *
*                                                                              *
*     You should have received a copy of the GNU General Public License        *
*     along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
********************************************************************************/

#ifndef DIALOGCLUSTERINGHIERARCHICAL_H
#define DIALOGCLUSTERINGHIERARCHICAL_H

#include <QDialog>
#include "ui_dialogclusteringhierarchical.h"
 

class DialogClusteringHierarchical: public QDialog
{
	Q_OBJECT
public:
    DialogClusteringHierarchical (QWidget *parent = 0, QString preselectMatrix = "");
    ~DialogClusteringHierarchical();
public slots:
	void gatherData();
signals:
    void userChoices(const QString &matrix,
                     const QString &varLocation,
                     const QString &similarityMeasure,
                     const QString &linkageCriterion,
                     const bool &diagonal,
                     const bool &diagram);
private slots:
    void on_buttonBox_accepted();

    void on_buttonBox_rejected();

    void matrixChanged(const QString &matrix);
private:
    Ui::DialogClusteringHierarchical ui;
    QStringList matrixList, measureList, linkageList, variablesLocationList;

};



#endif
